.. _user_guides:

Guides for users
==================================================

The Guides for users section includes SDG usage for different scenarios.

.. toctree::
    :maxdepth: 2

        Use CLI directly <cli>
        Use SDG as a library <library>
        Synthetic single-table data <single_table>
        Synthetic single-table data with specific_combinations <single_table_column_combinations>
        Synthetic multi-table data <multi_table>
        Evaluation synthetic data <evaluation>
